==> nextcloud-app-calendar-1.6.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/he.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "יומן",
    "Hello," : "שלום,",
    "Open »%s«" : "פתיחת „%s”",
    "Cheers!" : "ברכותינו!",
    "Too many redirects. Aborting ..." : "יותר מדי הפניות. התהליך מבוטל…",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "השרת המרוחק לא העניק לנו גישה ללוח השנה (שגיאת HTTP {%s})",
    "Error connecting to remote server" : "שגיאה בהתחברות לשרת המרוחק",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "שגיאה בבקשת משאב בשרת מרוחק. הסיבה עלולה להיות קשורה לחוסר התאמה באישורים",
    "Error requesting resource on remote server" : "שגיאה בבקשת משאב בשרת מרוחק",
    "Individual" : "פרטני",
    "Group" : "קבוצה",
    "Resource" : "משאב",
    "Room" : "חדר",
    "Unknown" : "לא ידוע",
    "Required" : "נדרש",
    "Optional" : "אופציונלי",
    "Does not attend" : "לא משתתף",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "הנך באזור זמן לא ידוע ({tz}), מעביר חזרה לאזור זמן UTC",
    "Please create a calendar first." : "יש ליצור לוח שנה תחילה.",
    "New event" : "אירוע חדש",
    "CalDAV address for clients" : "כתובת CalDAV ללקוחות",
    "Some events in this calendar are broken. Please check the JS console for more info." : "אירועים מסויימים בלוח שנה זה פגומים. יש לבדוק את קונסולת ה- JS למידע נוסף.",
    "Share Calendar" : "שיתוף לוח שנה",
    "Shared" : "שותף",
    "Could not save WebCal-calendar" : "לא ניתן לשמור לוח שנה מסוג WebCal",
    "WebDAV address for subscriptions" : "כתובת WebDAV להרשמה",
    "Email sent." : "נשלחה הודעה בדוא״ל.",
    "Could not send your email." : "לא ניתן לשלוח את הדוא״ל שלך.",
    "group" : "קבוצה",
    "Details" : "פרטים",
    "Attendees" : "משתתפים",
    "Reminders" : "תזכורות",
    "Repeating" : "חוזר",
    "When shared show full event" : "כאשר משותף מציג אירוע מלא",
    "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
    "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
    "Confirmed" : "מאושר",
    "Tentative" : "אישור טנטטיבי",
    "Cancelled" : "בוטל",
    "Please add a title." : "נא להוסיף כותרת.",
    "Please select a calendar." : "נא לבחור לוח שנה.",
    "The event can not end before it starts." : "האירוע לא יכול להסתיים בטרם התחלתו.",
    "Global" : "גלובלי",
    "None" : "כלום",
    "Every day" : "כל יום",
    "Every week" : "כל שבוע",
    "Every month" : "כל חודש",
    "Every year" : "כל שנה",
    "never" : "לעולם לא",
    "after" : "לאחר",
    "Automatic ({timezone})" : "אוטומטי ({timezone})",
    "How about getting started by importing some calendars?" : "אולי נתחיל בייבוא של כמה לוחות שנה?",
    "At time of event" : "בזמן אירוע",
    "5 minutes before" : "5 דקות לפני",
    "10 minutes before" : "10 דקות לפני",
    "15 minutes before" : "15 דקות לפני",
    "30 minutes before" : "30 דקות לפני",
    "1 hour before" : "1 שעה לפני",
    "2 hours before" : "2 שעות לפני",
    "Custom" : "מותאם אישית",
    "Audio" : "קובץ שמע",
    "Email" : "דוא״ל",
    "Pop-up" : "חלון קופץ",
    "sec" : "שניות",
    "min" : "דקות",
    "hours" : "שעות",
    "days" : "ימים",
    "week" : "שבוע",
    "before" : "לפני",
    "start" : "התחלה",
    "end" : "סוף",
    "Editing reminders of unknown type not supported." : "עריכת תזכורות מסוגים לא מוכרים אינה נתמכת.",
    "Week {number} of {year}" : "שבוע {number} ב־{year}",
    "Successfully imported {imported} objects" : "{imported} פריטים ייובאו בהצלחה",
    "Imported {imported} out of {all}, skipped one duplicate" : "ייובאו {imported} מתוך {all}, רשומה כפולה נזנחה",
    "Imported {imported} out of {all}, one failure" : "ייובאו {imported} מתוך {all}, כשל אחד",
    "Imported {imported} out of {all}, {errors} failures" : "ייובאו {imported} מתוך {all},‏ {errors} כשלים",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "ייובאו {imported} מתוך {all}, {duplicates} כפולים נזנחו",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "ייובאו {imported} מתוך {all},‏ {errors} כשלים, {duplicates} כפולים נזנחו",
    "Pop-up {time} before the event starts" : "הקפצה {time} לפני תחילת האירוע",
    "Email {time} before the event starts" : "שליחת דוא״ל {time} לפני תחילת האירוע",
    "None {time} before the event starts" : "לא לעשות כלום {time} לפני תחילת האירוע",
    "{type} {time} before the event starts" : "{type} {time} לפני תחילת האירוע",
    "{type} {time} before the event ends" : "{type} {time} לפני סיום האירוע",
    "{type} {time} after the event starts" : "{type} {time} אחרי תחילת האירוע",
    "{type} {time} after the event ends" : "{type} {time} אחרי סיום האירוע",
    "{type} at the event's start" : "{type} בתחילת האירוע",
    "{type} at the event's end" : "{type} בסיום האירוע",
    "{type} at {time}" : "{type} בשעה {time}",
    "{calendar} shared by {owner}" : "{calendar} משותף על ידי {owner}",
    "Please enter a valid WebCal-URL" : "יש להכניס נתיב אינטרנט WebCal חוקי",
    "A Calendar app for Nextcloud" : "יישומון לוח שנה ל־Nextcloud",
    "Title of the Event" : "כותרת האירוע",
    "Starts" : "מתחיל",
    "Ends" : "מסתיים",
    "All day Event" : "אירוע יום מלא",
    "Delete" : "מחיקה",
    "Cancel" : "ביטול",
    "More ..." : "עוד...",
    "Create" : "יצירה",
    "Update" : "עדכון",
    "Close" : "סגירה",
    "Location" : "מיקום",
    "Description" : "תיאור",
    "Event status" : "סטטוס אירוע",
    "Visibility when sharing" : "הרשאות צפייה כשמשתפים",
    "Export" : "ייצוא",
    "Click here to access it" : "יש ללחוץ כאן כדי לגשת אליו",
    "Click on the link below to access it" : "יש ללחוץ על הקישור להלן כדי לגשת אליו",
    "Day" : "יום",
    "Week" : "שבוע",
    "Month" : "חודש",
    "Today" : "היום",
    "More" : "יותר",
    "Edit" : "עריכה",
    "Link" : "קישור",
    "iCal link" : "קישור iCal",
    "Download" : "הורדה",
    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
    "can edit" : "ניתן לערוך",
    "Share link" : "שיתוף קישור",
    "Public access" : "גישה ציבורית",
    "Email link to person" : "שליחת קישור לאיש קשר בדוא״ל",
    "Send" : "שליחה",
    "New Calendar" : "לוח שנה חדש",
    "Name" : "שם",
    "New Subscription" : "מנוי חדש",
    "Go back" : "חזרה",
    "Go forward" : "קדימה",
    "Calendar does not exist" : "לוח השנה לא קיים",
    "Maybe you got a wrong link or the calendar was unshared?" : "אולי הקישור לא נכון או ששיתוף לוח השנה הופסק?",
    "Edit event" : "עריכת אירוע",
    "Delete Event" : "מחיקת אירוע",
    "Save Event" : "שמירת אירוע",
    "Time" : "זמן",
    "Type" : "סוג",
    "Relative" : "יחסי",
    "Absolute" : "מוחלט",
    "Repeat" : "חזרה",
    "times every" : "פעמים כל",
    "Add" : "הוספה",
    "Email address of attendee" : "כתובת הדוא״ל של המשתתף",
    "Please add your email address in the personal settings in order to add attendees." : "יש להזין את כתובת הדואר האלקטרוני שלך בהגדרות האישיות בכדי להוסיף מוזמנים.",
    "from" : "מאת",
    "to" : "אל",
    "This event's repeating rule is not supported yet." : "כלל חזרה לאירוע זה עדיין אינו נתמך.",
    "Support for advanced rules will be added with subsequent updates." : "תמיכת כללים מתקדמים תתווסף עם עדכונים מאוחרים יותר.",
    "Reset repeating rule" : "איפוס כלל חזרה",
    "Repeat every ..." : "חזרה כל...",
    "end repeat ..." : "סיום חזרה...",
    "times" : "פעמים",
    "Import Calendars" : "יבוא יומנים",
    "Import canceled" : "יבוא בוטל",
    "Analyzing calendar" : "מנתח יומן",
    "The file contains objects incompatible with the selected calendar" : "הקובץ כולל אוביקטים שאינם נתמכים על ידי היומן הנבחר",
    "New calendar" : "לוח שנה חדש",
    "File is empty" : "הקובץ ריק",
    "File could not be parsed" : "לא ניתן לפענח את הקובץ",
    "Import scheduled" : "לוח זמנים ליבוא",
    "Embed" : "הטמעה",
    "Iframe to integrate" : "Iframe (מסגרת פנימית) להטמעה",
    "Publish URL" : "פרסום כתובת",
    "Settings & import" : "הגדרות וייבוא",
    "Import calendar" : "ייבוא יומן",
    "No Calendars selected for import" : "לא נבחרו יומנים לייבוא",
    "Skip simple event editor" : "דילוג על עורך אירוע פשוט",
    "Show week numbers" : "הצגת מספרי שבועות",
    "Timezone" : "אזור זמן",
    "Primary CalDAV address" : "כתובת CalDAV ראשית",
    "iOS/macOS CalDAV address" : "כתובת CalDAV ל־iOS/macOS",
    "Subscribe" : "הרשמה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-app-calendar-1.6.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/he.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "יומן",
    "Hello," : "שלום,",
    "Open »%s«" : "פתיחת „%s”",
    "Cheers!" : "ברכותינו!",
    "Too many redirects. Aborting ..." : "יותר מדי הפניות. התהליך מבוטל…",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "השרת המרוחק לא העניק לנו גישה ללוח השנה (שגיאת HTTP {%s})",
    "Error connecting to remote server" : "שגיאה בהתחברות לשרת המרוחק",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "שגיאה בבקשת משאב בשרת מרוחק. הסיבה עלולה להיות קשורה לחוסר התאמה באישורים",
    "Error requesting resource on remote server" : "שגיאה בבקשת משאב בשרת מרוחק",
    "Individual" : "פרטני",
    "Group" : "קבוצה",
    "Resource" : "משאב",
    "Room" : "חדר",
    "Unknown" : "לא ידוע",
    "Required" : "נדרש",
    "Optional" : "אופציונלי",
    "Does not attend" : "לא משתתף",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "הנך באזור זמן לא ידוע ({tz}), מעביר חזרה לאזור זמן UTC",
    "Please create a calendar first." : "יש ליצור לוח שנה תחילה.",
    "New event" : "אירוע חדש",
    "CalDAV address for clients" : "כתובת CalDAV ללקוחות",
    "Some events in this calendar are broken. Please check the JS console for more info." : "אירועים מסויימים בלוח שנה זה פגומים. יש לבדוק את קונסולת ה- JS למידע נוסף.",
    "Share Calendar" : "שיתוף לוח שנה",
    "Shared" : "שותף",
    "Could not save WebCal-calendar" : "לא ניתן לשמור לוח שנה מסוג WebCal",
    "WebDAV address for subscriptions" : "כתובת WebDAV להרשמה",
    "Email sent." : "נשלחה הודעה בדוא״ל.",
    "Could not send your email." : "לא ניתן לשלוח את הדוא״ל שלך.",
    "group" : "קבוצה",
    "Details" : "פרטים",
    "Attendees" : "משתתפים",
    "Reminders" : "תזכורות",
    "Repeating" : "חוזר",
    "When shared show full event" : "כאשר משותף מציג אירוע מלא",
    "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
    "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
    "Confirmed" : "מאושר",
    "Tentative" : "אישור טנטטיבי",
    "Cancelled" : "בוטל",
    "Please add a title." : "נא להוסיף כותרת.",
    "Please select a calendar." : "נא לבחור לוח שנה.",
    "The event can not end before it starts." : "האירוע לא יכול להסתיים בטרם התחלתו.",
    "Global" : "גלובלי",
    "None" : "כלום",
    "Every day" : "כל יום",
    "Every week" : "כל שבוע",
    "Every month" : "כל חודש",
    "Every year" : "כל שנה",
    "never" : "לעולם לא",
    "after" : "לאחר",
    "Automatic ({timezone})" : "אוטומטי ({timezone})",
    "How about getting started by importing some calendars?" : "אולי נתחיל בייבוא של כמה לוחות שנה?",
    "At time of event" : "בזמן אירוע",
    "5 minutes before" : "5 דקות לפני",
    "10 minutes before" : "10 דקות לפני",
    "15 minutes before" : "15 דקות לפני",
    "30 minutes before" : "30 דקות לפני",
    "1 hour before" : "1 שעה לפני",
    "2 hours before" : "2 שעות לפני",
    "Custom" : "מותאם אישית",
    "Audio" : "קובץ שמע",
    "Email" : "דוא״ל",
    "Pop-up" : "חלון קופץ",
    "sec" : "שניות",
    "min" : "דקות",
    "hours" : "שעות",
    "days" : "ימים",
    "week" : "שבוע",
    "before" : "לפני",
    "start" : "התחלה",
    "end" : "סוף",
    "Editing reminders of unknown type not supported." : "עריכת תזכורות מסוגים לא מוכרים אינה נתמכת.",
    "Week {number} of {year}" : "שבוע {number} ב־{year}",
    "Successfully imported {imported} objects" : "{imported} פריטים ייובאו בהצלחה",
    "Imported {imported} out of {all}, skipped one duplicate" : "ייובאו {imported} מתוך {all}, רשומה כפולה נזנחה",
    "Imported {imported} out of {all}, one failure" : "ייובאו {imported} מתוך {all}, כשל אחד",
    "Imported {imported} out of {all}, {errors} failures" : "ייובאו {imported} מתוך {all},‏ {errors} כשלים",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "ייובאו {imported} מתוך {all}, {duplicates} כפולים נזנחו",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "ייובאו {imported} מתוך {all},‏ {errors} כשלים, {duplicates} כפולים נזנחו",
    "Pop-up {time} before the event starts" : "הקפצה {time} לפני תחילת האירוע",
    "Email {time} before the event starts" : "שליחת דוא״ל {time} לפני תחילת האירוע",
    "None {time} before the event starts" : "לא לעשות כלום {time} לפני תחילת האירוע",
    "{type} {time} before the event starts" : "{type} {time} לפני תחילת האירוע",
    "{type} {time} before the event ends" : "{type} {time} לפני סיום האירוע",
    "{type} {time} after the event starts" : "{type} {time} אחרי תחילת האירוע",
    "{type} {time} after the event ends" : "{type} {time} אחרי סיום האירוע",
    "Pop-up at the event's start" : "חלון קופץ עם תחילת האירוע",
    "Email at the event's start" : "דוא״ל עם התחלת האירוע",
    "None at the event's start" : "לא לעשות כלום עם התחלת האירוע",
    "{type} at the event's start" : "{type} בתחילת האירוע",
    "{type} at the event's end" : "{type} בסיום האירוע",
    "{type} at {time}" : "{type} בשעה {time}",
    "{calendar} shared by {owner}" : "{calendar} משותף על ידי {owner}",
    "Please enter a valid WebCal-URL" : "יש להכניס נתיב אינטרנט WebCal חוקי",
    "Severe error in webcal proxy. Please contact administrator for more information." : "שגיאה חמורה במתווך ה־webcal. נא ליצור קשר לקבלת מידע נוסף.",
    "A Calendar app for Nextcloud" : "יישומון לוח שנה ל־Nextcloud",
    "Title of the Event" : "כותרת האירוע",
    "Starts" : "מתחיל",
    "Ends" : "מסתיים",
    "All day Event" : "אירוע יום מלא",
    "Delete" : "מחיקה",
    "Cancel" : "ביטול",
    "More ..." : "עוד...",
    "Create" : "יצירה",
    "Update" : "עדכון",
    "Close" : "סגירה",
    "Location" : "מיקום",
    "Description" : "תיאור",
    "Event status" : "סטטוס אירוע",
    "Visibility when sharing" : "הרשאות צפייה כשמשתפים",
    "Export" : "ייצוא",
    "%s has published the calendar %s" : "היומן %s פורסם על ידי %s",
    "Click here to access it" : "יש ללחוץ כאן כדי לגשת אליו",
    "Click on the link below to access it" : "יש ללחוץ על הקישור להלן כדי לגשת אליו",
    "Day" : "יום",
    "Week" : "שבוע",
    "Month" : "חודש",
    "Today" : "היום",
    "More" : "יותר",
    "Edit" : "עריכה",
    "Link" : "קישור",
    "iCal link" : "קישור iCal",
    "Download" : "הורדה",
    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
    "can edit" : "ניתן לערוך",
    "Share link" : "שיתוף קישור",
    "Public access" : "גישה ציבורית",
    "Email link to person" : "שליחת קישור לאיש קשר בדוא״ל",
    "Send" : "שליחה",
    "New Calendar" : "לוח שנה חדש",
    "Name" : "שם",
    "New Subscription" : "מנוי חדש",
    "Go back" : "חזרה",
    "Go forward" : "קדימה",
    "Calendar does not exist" : "לוח השנה לא קיים",
    "Maybe you got a wrong link or the calendar was unshared?" : "אולי הקישור לא נכון או ששיתוף לוח השנה הופסק?",
    "Edit event" : "עריכת אירוע",
    "Delete Event" : "מחיקת אירוע",
    "Save Event" : "שמירת אירוע",
    "Time" : "זמן",
    "Type" : "סוג",
    "Relative" : "יחסי",
    "Absolute" : "מוחלט",
    "Repeat" : "חזרה",
    "times every" : "פעמים כל",
    "Add" : "הוספה",
    "Email address of attendee" : "כתובת הדוא״ל של המשתתף",
    "Please add your email address in the personal settings in order to add attendees." : "יש להזין את כתובת הדואר האלקטרוני שלך בהגדרות האישיות בכדי להוסיף מוזמנים.",
    "from" : "מאת",
    "to" : "אל",
    "This event's repeating rule is not supported yet." : "כלל חזרה לאירוע זה עדיין אינו נתמך.",
    "Support for advanced rules will be added with subsequent updates." : "תמיכת כללים מתקדמים תתווסף עם עדכונים מאוחרים יותר.",
    "Reset repeating rule" : "איפוס כלל חזרה",
    "Repeat every ..." : "חזרה כל...",
    "end repeat ..." : "סיום חזרה...",
    "times" : "פעמים",
    "Import Calendars" : "יבוא יומנים",
    "Import canceled" : "יבוא בוטל",
    "Analyzing calendar" : "מנתח יומן",
    "The file contains objects incompatible with the selected calendar" : "הקובץ כולל אוביקטים שאינם נתמכים על ידי היומן הנבחר",
    "New calendar" : "לוח שנה חדש",
    "File is empty" : "הקובץ ריק",
    "File could not be parsed" : "לא ניתן לפענח את הקובץ",
    "Import scheduled" : "לוח זמנים ליבוא",
    "Embed" : "הטמעה",
    "Iframe to integrate" : "Iframe (מסגרת פנימית) להטמעה",
    "Publish URL" : "פרסום כתובת",
    "Settings & import" : "הגדרות וייבוא",
    "Import calendar" : "ייבוא יומן",
    "No Calendars selected for import" : "לא נבחרו יומנים לייבוא",
    "Skip simple event editor" : "דילוג על עורך אירוע פשוט",
    "Show week numbers" : "הצגת מספרי שבועות",
    "Timezone" : "אזור זמן",
    "Primary CalDAV address" : "כתובת CalDAV ראשית",
    "iOS/macOS CalDAV address" : "כתובת CalDAV ל־iOS/macOS",
    "Subscribe" : "הרשמה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
